slepc-3.18.0 2022-10-01
Report Typos and Errors

# EPSPRIMMESetMethod

Sets the method for the PRIMME library.

### Synopsis

    #include "slepceps.h"
    PetscErrorCode EPSPRIMMESetMethod(EPS eps,EPSPRIMMEMethod method)

Logically Collective on eps

### Input Parameters

| eps | - the eigenproblem solver context
| method | - method that will be used by PRIMME

### Options Database Key

| -eps_primme_method | - Sets the method for the PRIMME library

### Note

If not set, the method defaults to EPS_PRIMME_DEFAULT_MIN_TIME.

### See Also

EPSPRIMMEGetMethod(), EPSPRIMMEMethod

### Level

advanced

### Location

src/eps/impls/external/primme/primme.c
Index of all EPS routines
Table of Contents for all manual pages
Index of all manual pages